pub struct ResultCode(/* private fields */);Implementations
Sourceimpl ResultCode
impl ResultCode
Sourcepub const Ok: Self
pub const Ok: Self
Indicates that the last operation was successful or operation is in progress.
Sourcepub const ErrProduct: Self
pub const ErrProduct: Self
Indicates that the AC is not for the current product/version.
Sourcepub const ErrProductPh2: Self
pub const ErrProductPh2: Self
Indicates that the AC in the second phase is not for the current product/version.
Sourcepub const ErrTransfer: Self
pub const ErrTransfer: Self
Indicates that the AC is corrupted.
Sourcepub const ErrTransferPh2: Self
pub const ErrTransferPh2: Self
Indicates that the AC in the second phase is corrupted.
Sourcepub const ErrAuthPh2: Self
pub const ErrAuthPh2: Self
Indicates that the authentication of the provided AC failed in the second phase.
Sourcepub const ErrPufQuality: Self
pub const ErrPufQuality: Self
Indicates that the SRAM PUF quality verification fails.
Sourcepub const ErrContext: Self
pub const ErrContext: Self
Indicates that the incorrect or unsupported context is provided.
Sourcepub const ErrDestination: Self
pub const ErrDestination: Self
Indicates that a data destination was set that is not allowed according to other settings and the current PUF state.
Sourceimpl ResultCode
impl ResultCode